==> cert_creation-1.3.15.241227-sources.jar: com/xdja/safeclient/certcreation/bean/response/CompareResult.java <==
package com.xdja.safeclient.certcreation.bean.response;

import java.io.Serializable;

/**
 * Created by yangpeng on 2018/4/19.
 */

public class CompareResult extends CommonResponse implements Serializable {

    private boolean isSuccess;
    private String result;
    private String hostId;
    private String requestId;
    private String errCode;
    private String message;
    private String identity;
    private String dn;
    private String sig;

    public String getDn() {
        return dn;
    }

    public String getSig() {
        return sig;
    }

    public CompareResult() {

    }

    public boolean isSuccess() {
        return isSuccess;
    }

    public String getIdentity() {
        return identity;
    }

    public void setIdentity(String identity) {
        this.identity = identity;
    }

    public void setSuccess(boolean success) {
        isSuccess = success;
    }

    public String getResult() {
        return result;
    }

    public void setResult(String result) {
        this.result = result;
    }

    public String getHostId() {
        return hostId;
    }

    public void setHostId(String hostId) {
        this.hostId = hostId;
    }

    public String getRequestId() {
        return requestId;
    }

    public void setRequestId(String requestId) {
        this.requestId = requestId;
    }

    public String getErrCode() {
        return errCode;
    }

    public void setErrCode(String errCode) {
        this.errCode = errCode;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }


    public void setDn(String dn) {
        this.dn = dn;
    }

    public void setSig(String sig) {
        this.sig = sig;
    }

    @Override
    public String toString() {
        return "CompareResult{" +
                "isSuccess=" + isSuccess +
                ", result='" + result + '\'' +
                ", hostId='" + hostId + '\'' +
                ", requestId='" + requestId + '\'' +
                ", errCode='" + errCode + '\'' +
                ", message='" + message + '\'' +
                ", identity='" + identity + '\'' +
                ", dn='" + dn + '\'' +
                ", sig='" + sig + '\'' +
                '}';
    }
}

==> cert_creation-1.8.1_3-sources.jar: com/xdja/safeclient/certcreation/bean/response/CompareResult.java <==
package com.xdja.safeclient.certcreation.bean.response;

import java.io.Serializable;

/**
 * Created by yangpeng on 2018/4/19.
 */

public class CompareResult extends CommonResponse implements Serializable {

    private boolean isSuccess;
    private String result;
    private String hostId;
    private String requestId;
    private String errCode;
    private String message;
    private String identity;

    public CompareResult() {

    }

    public boolean isSuccess() {
        return isSuccess;
    }

    public String getIdentity() {
        return identity;
    }

    public void setIdentity(String identity) {
        this.identity = identity;
    }

    public void setSuccess(boolean success) {
        isSuccess = success;
    }

    public String getResult() {
        return result;
    }

    public void setResult(String result) {
        this.result = result;
    }

    public String getHostId() {
        return hostId;
    }

    public void setHostId(String hostId) {
        this.hostId = hostId;
    }

    public String getRequestId() {
        return requestId;
    }

    public void setRequestId(String requestId) {
        this.requestId = requestId;
    }

    public String getErrCode() {
        return errCode;
    }

    public void setErrCode(String errCode) {
        this.errCode = errCode;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    @Override
    public String toString() {
        return "{" +
                "isSuccess=" + isSuccess +
                ",result='" + result + '\'' +
                ",hostId='" + hostId + '\'' +
                ",requestId='" + requestId + '\'' +
                ",errCode='" + errCode + '\'' +
                ",message='" + message + '\'' +
                ",identity='" + identity + '\'' +
                '}';
    }


}
